import { Card } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { PieChart, Pie, Cell, ResponsiveContainer } from 'recharts';
import { Check } from 'lucide-react';

const benefits = [
  "Up to 50% Commission",
  "Real-time Performance Dashboard",
  "Instant Payouts for All Conversions",
  "Detailed Reporting & AI Performance Dashboard"
];

const pieData = [
  { name: 'Win', value: 78 },
  { name: 'Loss', value: 22 },
];

const COLORS = ['#26E16A', '#2B2B3F'];

export default function AffiliatesSection() {
  return (
    <div className="bg-background py-16" id="affiliate">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="text-center mb-16">
          <h2 className="text-3xl font-bold mb-4">Affiliate Program</h2>
          <p className="text-gray-300 max-w-3xl mx-auto">
            Join thousands of successful affiliates who are already earning with our platform. Our high-converting offers and instant payouts make us the preferred choice.
          </p>
        </div>
        
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-8 items-center">
          <div>
            <ul className="space-y-4">
              {benefits.map((benefit, index) => (
                <li key={index} className="flex items-center">
                  <div className="h-6 w-6 rounded-full bg-accent/20 flex items-center justify-center flex-shrink-0 mr-3">
                    <Check className="h-4 w-4 text-accent" />
                  </div>
                  <span>{benefit}</span>
                </li>
              ))}
            </ul>
            
            <div className="mt-8">
              <a 
                href="https://t.me/SuperQuikieBot" 
                target="_blank" 
                rel="noopener noreferrer"
              >
                <Button size="lg" className="font-medium">Become an Affiliate</Button>
              </a>
            </div>
          </div>
          
          <Card className="bg-secondary border-none shadow-lg overflow-hidden">
            <div className="p-6">
              <h3 className="text-xl font-bold mb-6">Affiliate Performance</h3>
              
              <div className="flex items-center">
                <div className="w-1/2">
                  <div className="mb-4">
                    <div className="text-sm text-gray-400">Conversion Rate</div>
                    <div className="text-2xl font-mono text-[#26E16A]">78%</div>
                  </div>
                  <div>
                    <div className="text-sm text-gray-400">Avg. Commission</div>
                    <div className="text-2xl font-mono text-[#26E16A]">$423</div>
                  </div>
                </div>
                
                <div className="w-1/2 h-40">
                  <ResponsiveContainer width="100%" height="100%">
                    <PieChart>
                      <Pie
                        data={pieData}
                        cx="50%"
                        cy="50%"
                        innerRadius={45}
                        outerRadius={60}
                        fill="#8884d8"
                        dataKey="value"
                      >
                        {pieData.map((entry, index) => (
                          <Cell key={`cell-${index}`} fill={COLORS[index % COLORS.length]} />
                        ))}
                      </Pie>
                    </PieChart>
                  </ResponsiveContainer>
                </div>
              </div>
            </div>
          </Card>
        </div>
      </div>
    </div>
  );
}
