import { useEffect, useState } from 'react';
import { GlowEffect } from '@/components/ui/glow-effect';
import { MovingBorder } from '@/components/ui/moving-border';

interface ExecutionSpeedCardProps {
  initialSpeed?: string;
  successRate?: string;
  tokenName?: string;
}

export function ExecutionSpeedCard({
  initialSpeed = "0.3s",
  successRate = "98.7%",
  tokenName = "New Token Sniping"
}: ExecutionSpeedCardProps) {
  const [isBlinking, setIsBlinking] = useState(false);
  
  // Create beeping animation effect
  useEffect(() => {
    const blinkInterval = setInterval(() => {
      setIsBlinking(true);
      
      // Reset blink after very short duration
      setTimeout(() => {
        setIsBlinking(false);
      }, 80); // Faster blink
    }, 500); // Blink every 0.5 seconds
    
    return () => clearInterval(blinkInterval);
  }, []);

  return (
    <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 -mt-8 relative z-20">
      <div 
        className="relative rounded-xl overflow-hidden p-[1px]"
      >
        {/* Moving border animation */}
        <div className="absolute inset-0">
          <MovingBorder duration={2000} rx="12px" ry="12px">
            <div className="h-32 w-32 opacity-[0.8] bg-[radial-gradient(#00e676_40%,transparent_60%)]" />
          </MovingBorder>
        </div>
        
        <div 
          className="flex flex-col md:flex-row items-center justify-between py-6 px-8 rounded-xl relative z-10"
          style={{
            background: 'linear-gradient(to right, rgba(0, 0, 0, 0.95), rgba(0, 0, 0, 0.9))',
          }}
        >
          <div className="text-gray-300 font-medium">
            {tokenName}
          </div>
          
          <div className="text-center my-4 md:my-0">
            <div 
              className={`text-3xl md:text-4xl font-mono font-bold ${isBlinking ? 'opacity-30' : 'opacity-100'}`}
              style={{ 
                color: '#00e676',
                transition: 'opacity 0.03s ease-in-out',
              }}
            >
              {initialSpeed} <span className="text-gray-300 font-normal">Average Execution Speed</span>
            </div>
          </div>
          
          <div className="text-gray-300 font-medium">
            {successRate} Success Rate
          </div>
        </div>
      </div>
    </div>
  );
}