import { useState } from 'react';
import { 
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger
} from '@/components/ui/accordion';
import { Card } from '@/components/ui/card';

const faqs = [
  {
    question: "How fast is Quikie Bot trade execution?",
    answer: "Quikie Bot offers ultra-fast trade execution with an average speed of less than 3 seconds on the Binance Smart Chain. Our optimized Telegram-native interface ensures your trades are processed with minimal latency, giving you a significant advantage when trading BSC tokens."
  },
  {
    question: "How does Quikie Bot's contract safety scanner work?",
    answer: "Our AI-powered contract safety scanner automatically analyzes BSC token smart contracts for potential risks, vulnerabilities, and malicious code. It checks for honeypots, rugpull indicators, and other common scam patterns to help you trade safely in the BSC ecosystem."
  },
  {
    question: "Can I use Quikie Bot directly in Telegram?",
    answer: "Yes! Quikie Bot is fully Telegram-native. There's no need to download any external applications. Simply connect your wallet, scan the token you want to trade, and execute trades directly through our secure Telegram bot interface in seconds."
  },
  {
    question: "What tokens can I trade with Quikie Bot?",
    answer: "Quikie Bot supports all tokens on the Binance Smart Chain (BSC). You can easily trade popular tokens like PancakeSwap, 4Meme, BabyDoge, and thousands of other BSC tokens with just a few simple commands in Telegram."
  },
  {
    question: "How does the affiliate program work?",
    answer: "Our affiliate program allows you to earn passive income by referring others to Quikie Bot. You'll receive a percentage of the trading fees generated by your referrals. The more active traders you refer, the more rewards you'll earn. It's designed by degens for degens to maximize your earnings."
  }
];

export default function FaqSection() {
  return (
    <div className="bg-background py-16" id="faq">
      <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="text-center mb-16">
          <h2 className="text-3xl font-bold mb-4">Frequently Asked Questions</h2>
          <p className="text-gray-300">
            Find answers to common questions about our Telegram-native BSC trading bot.
          </p>
        </div>
        
        <Accordion type="single" collapsible className="space-y-4">
          {faqs.map((faq, index) => (
            <AccordionItem value={`item-${index}`} key={index} className="border-none">
              <Card className="bg-secondary border-none">
                <AccordionTrigger className="px-6 py-4 text-left font-medium hover:no-underline">
                  {faq.question}
                </AccordionTrigger>
                <AccordionContent>
                  <div className="px-6 pb-4 pt-2 border-t border-gray-700">
                    <p className="text-gray-300">{faq.answer}</p>
                  </div>
                </AccordionContent>
              </Card>
            </AccordionItem>
          ))}
        </Accordion>
      </div>
    </div>
  );
}
