import { Card, CardContent } from '@/components/ui/card';
import { 
  Zap, 
  LineChart, 
  ShieldCheck,
  Bot,
  Repeat,
  BarChart4,
  Brain
} from 'lucide-react';
import { motion } from 'framer-motion';

const features = [
  {
    title: '⚡ 3s Token Execution',
    description: 'Lightning-fast token execution ensures you never miss opportunities in volatile markets.',
    icon: <Zap className="h-8 w-8" />,
    gradient: 'from-[#00c2ff] to-[#00e4ff]'
  },
  {
    title: '🔐 Smart Contract Safety',
    description: 'Our advanced security protocols analyze contracts before execution to prevent scams and vulnerabilities.',
    icon: <ShieldCheck className="h-8 w-8" />,
    gradient: 'from-[#00b894] to-[#00d68f]'
  },
  {
    title: '🤖 AI-Powered Price Detection',
    description: 'Machine learning algorithms detect optimal entry and exit points based on market patterns.',
    icon: <Bot className="h-8 w-8" />,
    gradient: 'from-[#6c5ce7] to-[#a29bfe]'
  },
  {
    title: '🔁 1-Tap Token Swaps',
    description: 'Seamlessly swap tokens with a single tap, optimizing for the best rates across multiple DEXs.',
    icon: <Repeat className="h-8 w-8" />,
    gradient: 'from-[#e84393] to-[#fd79a8]'
  },
  {
    title: '📊 Animated Speed Graph',
    description: 'Fluid, real-time visualization of network speed and transaction throughput for optimal trading.',
    icon: <BarChart4 className="h-8 w-8" />,
    gradient: 'from-[#fdcb6e] to-[#ffeaa7]'
  },
  {
    title: '🧠 Front-run Protection',
    description: 'Proprietary anti-front-running technology prevents bots from stealing your transaction profits.',
    icon: <Brain className="h-8 w-8" />,
    gradient: 'from-[#e17055] to-[#fab1a0]'
  }
];

export default function FeatureSection() {
  return (
    <div className="bg-background py-24">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8" id="features">
        <div className="text-center mb-16">
          <h2 className="text-4xl md:text-5xl font-bold mb-4">Features</h2>
          <p className="text-gray-300 max-w-3xl mx-auto text-lg">
            Our cutting-edge platform delivers unmatched speed, security, and performance for cryptocurrency trading.
          </p>
        </div>
        
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
          {features.map((feature, index) => (
            <motion.div
              key={index}
              className="h-full"
              whileHover={{ 
                y: -10,
                transition: { type: 'spring', stiffness: 300 }
              }}
            >
              <Card 
                className="h-full bg-secondary/20 backdrop-blur-sm border border-accent/10 overflow-hidden relative group"
              >
                {/* Gradient background that shows on hover */}
                <div 
                  className={`absolute inset-0 bg-gradient-to-br ${feature.gradient} opacity-0 group-hover:opacity-10 transition-opacity duration-300`}
                />
                
                {/* Glow effect on hover */}
                <div className="absolute -inset-0.5 bg-gradient-to-br opacity-0 group-hover:opacity-50 blur-md transition-opacity duration-300 -z-10"
                  style={{
                    background: `linear-gradient(to bottom right, ${feature.gradient.split('from-')[1].split(' ')[0]}, ${feature.gradient.split('to-')[1]})`
                  }}
                />
                
                <CardContent className="pt-8 pb-6 relative z-10">
                  <div className={`mb-6 rounded-full w-14 h-14 flex items-center justify-center bg-gradient-to-br ${feature.gradient}`}>
                    <div className="text-white">
                      {feature.icon}
                    </div>
                  </div>
                  <h3 className="text-xl font-bold mb-3">{feature.title}</h3>
                  <p className="text-gray-300">{feature.description}</p>
                </CardContent>
              </Card>
            </motion.div>
          ))}
        </div>
      </div>
    </div>
  );
}
