import { Link } from 'wouter';
import { Button } from '@/components/ui/button';
import { 
  FaTwitter, 
  FaTelegram,
  FaDiscord,
  FaYoutube 
} from 'react-icons/fa';
import logoImage from '../assets/logo.png';

export default function Footer() {
  const currentYear = new Date().getFullYear();
  
  return (
    <footer className="bg-background border-t border-secondary">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-12">
        <div className="grid grid-cols-1 md:grid-cols-2 gap-8">
          <div>
            <div className="mb-3 h-14 w-48 relative overflow-hidden">
              <div 
                className="absolute top-0 left-0 h-full w-full"
                style={{
                  backgroundImage: `url(${logoImage})`,
                  backgroundSize: 'contain',
                  backgroundPosition: 'left center',
                  backgroundRepeat: 'no-repeat',
                  transform: 'scale(2.5)',
                  transformOrigin: 'left center',
                }}
              />
            </div>
            <p className="text-gray-400 mb-4">
              AI-powered Telegram trading bot for BSC tokens with lightning-fast execution, advanced contract safety scanning, and intelligent trading insights.
            </p>
            <div className="flex space-x-4">
              <a href="#" className="text-gray-400 hover:text-accent transition-colors duration-200">
                <FaTwitter className="h-5 w-5" />
              </a>
              <a href="#" className="text-gray-400 hover:text-accent transition-colors duration-200">
                <FaTelegram className="h-5 w-5" />
              </a>
              <a href="#" className="text-gray-400 hover:text-accent transition-colors duration-200">
                <FaDiscord className="h-5 w-5" />
              </a>
              <a href="#" className="text-gray-400 hover:text-accent transition-colors duration-200">
                <FaYoutube className="h-5 w-5" />
              </a>
            </div>
          </div>
          
          <div>
            <h3 className="font-bold mb-4">Links</h3>
            <div className="grid grid-cols-2">
              <ul className="space-y-2">
                <li><Link href="#features" className="text-gray-400 hover:text-white transition-colors">Features</Link></li>
                <li><Link href="#affiliate" className="text-gray-400 hover:text-white transition-colors">Affiliate Program</Link></li>
                <li><Link href="#faq" className="text-gray-400 hover:text-white transition-colors">FAQ</Link></li>
              </ul>
              <ul className="space-y-2">
                <li><Link href="#" className="text-gray-400 hover:text-white transition-colors">Documentation</Link></li>
                <li><Link href="#" className="text-gray-400 hover:text-white transition-colors">Contact</Link></li>
                <li><Link href="#" className="text-gray-400 hover:text-white transition-colors">Terms & Privacy</Link></li>
              </ul>
            </div>
          </div>
        </div>
        
        <div className="mt-12 pt-8 border-t border-secondary">
          <div className="flex flex-col md:flex-row justify-between items-center">
            <p className="text-gray-400">© {currentYear} Quikie. All rights reserved.</p>
            <p className="text-gray-400 font-medium mt-4 md:mt-0 italic">Designed by Degens for Degens</p>
          </div>
        </div>
      </div>
    </footer>
  );
}
