import { Button } from '@/components/ui/button';
import { Zap, BookOpen } from 'lucide-react';
import { Waves } from '@/components/ui/waves-background';

export default function HeroSection() {
  return (
    <div className="relative bg-background overflow-hidden min-h-[90vh]">
      {/* Interactive Wave Background with increased interactivity */}
      <div className="absolute inset-0 w-full h-full">
        <Waves 
          lineColor="rgba(0, 200, 83, 0.25)"
          backgroundColor="transparent"
          waveSpeedX={0.018}
          waveSpeedY={0.01}
          waveAmpX={40}
          waveAmpY={25}
          friction={0.92}
          tension={0.01}
          maxCursorMove={200}
          xGap={10}
          yGap={30}
        />
      </div>

      {/* Static glowing overlay for additional effect */}
      <div className="absolute inset-0 pointer-events-none">
        <div className="absolute top-1/4 -left-10 w-72 h-72 bg-accent/20 rounded-full blur-[120px]" />
        <div className="absolute bottom-1/3 right-0 w-96 h-96 bg-accent/10 rounded-full blur-[120px]" />
      </div>

      <div className="relative z-10 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-24 md:py-32">
        <div className="flex flex-col items-start max-w-4xl">
          <div className="flex items-center mb-6 bg-accent/10 px-4 py-2 rounded-full">
            <Zap className="h-4 w-4 text-accent mr-2" />
            <span className="text-sm font-medium">Ultra fast bot</span>
          </div>
          
          <h1 className="text-5xl md:text-6xl font-extrabold tracking-tight mb-6 text-accent">
            Ultra-fast. Telegram-native. <span className="whitespace-nowrap">AI-powered.</span>
          </h1>
          
          <p className="text-gray-100 mb-10 text-2xl max-w-2xl font-medium leading-relaxed">
            AI-powered Telegram bot built for speed, simplicity, and security.
          </p>
          
          <div className="flex flex-col sm:flex-row gap-6 items-center">
            <a 
              href="https://t.me/SuperQuikieBot" 
              target="_blank" 
              rel="noopener noreferrer"
            >
              <Button size="lg" className="rounded-full px-8 py-6 text-base font-medium flex items-center gap-2">
                Start Trading
                <svg width="20" height="20" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M8.14645 3.14645C8.34171 2.95118 8.65829 2.95118 8.85355 3.14645L12.8536 7.14645C13.0488 7.34171 13.0488 7.65829 12.8536 7.85355L8.85355 11.8536C8.65829 12.0488 8.34171 12.0488 8.14645 11.8536C7.95118 11.6583 7.95118 11.3417 8.14645 11.1464L11.2929 8H2.5C2.22386 8 2 7.77614 2 7.5C2 7.22386 2.22386 7 2.5 7H11.2929L8.14645 3.85355C7.95118 3.65829 7.95118 3.34171 8.14645 3.14645Z" fill="currentColor" fillRule="evenodd" clipRule="evenodd"></path>
                </svg>
              </Button>
            </a>
            <a 
              href="https://t.me/SuperQuikieBot" 
              target="_blank"
              rel="noopener noreferrer"
              className="px-6 py-2.5 border border-gray-500 rounded-full hover:bg-accent/10 transition-colors font-medium flex items-center gap-2 group"
            >
              <BookOpen className="h-5 w-5 group-hover:text-accent transition-colors" />
              <span className="group-hover:text-accent transition-colors">Documentation</span>
            </a>
          </div>
        </div>
      </div>
    </div>
  );
}
