import { Button } from '@/components/ui/button';
import { useState } from 'react';
import { Link } from 'wouter';
import logoImage from '../assets/logo.png';
import { motion } from 'framer-motion';

export default function Navbar() {
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);

  return (
    <nav className="bg-background/80 backdrop-blur-md z-50 sticky top-0 py-2">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center">
          <div className="flex items-center">
            <div className="flex-shrink-0 flex items-center">
              <Link href="/" className="flex items-center">
                <motion.div 
                  whileHover={{ scale: 1.05 }}
                  whileTap={{ scale: 0.98 }}
                  className="h-12 w-[180px] overflow-hidden"
                  style={{
                    backgroundImage: `url(${logoImage})`,
                    backgroundSize: 'contain',
                    backgroundPosition: 'center',
                    backgroundRepeat: 'no-repeat',
                    transform: 'scale(2.5)',
                    marginLeft: '30px',
                    marginRight: '-10px',
                  }}
                >
                </motion.div>
              </Link>
            </div>
            <div className="hidden sm:ml-10 sm:flex sm:space-x-8">
              <Link 
                href="#" 
                className="text-white inline-flex items-center px-3 py-2 text-sm font-medium hover:text-accent transition-colors"
              >
                Home
              </Link>
              <Link 
                href="#features" 
                className="text-gray-300 inline-flex items-center px-3 py-2 text-sm font-medium hover:text-accent transition-colors"
              >
                Features
              </Link>
              <Link 
                href="#affiliate" 
                className="text-gray-300 inline-flex items-center px-3 py-2 text-sm font-medium hover:text-accent transition-colors"
              >
                Affiliate
              </Link>
              <Link 
                href="#faq" 
                className="text-gray-300 inline-flex items-center px-3 py-2 text-sm font-medium hover:text-accent transition-colors"
              >
                FAQ
              </Link>
            </div>
          </div>
          
          <div className="hidden sm:flex sm:items-center">
            <a 
              href="https://t.me/SuperQuikieBot" 
              target="_blank" 
              rel="noopener noreferrer"
            >
              <Button variant="default" size="sm" className="rounded-full px-6 text-sm font-medium uppercase">
                Get Started
              </Button>
            </a>
          </div>
          
          <div className="flex items-center sm:hidden">
            <button
              type="button"
              className="inline-flex items-center justify-center p-2 rounded-md text-gray-400 hover:text-white hover:bg-secondary/30 focus:outline-none"
              onClick={() => setMobileMenuOpen(!mobileMenuOpen)}
            >
              <span className="sr-only">Open main menu</span>
              {mobileMenuOpen ? (
                <svg className="block h-6 w-6" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" aria-hidden="true">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                </svg>
              ) : (
                <svg className="block h-6 w-6" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" aria-hidden="true">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M4 6h16M4 12h16M4 18h16" />
                </svg>
              )}
            </button>
          </div>
        </div>
      </div>

      {/* Mobile menu */}
      {mobileMenuOpen && (
        <div className="sm:hidden bg-background/95 backdrop-blur-md py-4 mt-2">
          <div className="px-4 pt-2 pb-3 space-y-1">
            <Link href="#" className="text-accent block px-3 py-2 text-base font-medium">
              Home
            </Link>
            <Link href="#features" className="text-gray-300 hover:text-accent block px-3 py-2 text-base font-medium">
              Features
            </Link>
            <Link href="#affiliate" className="text-gray-300 hover:text-accent block px-3 py-2 text-base font-medium">
              Affiliate
            </Link>
            <Link href="#faq" className="text-gray-300 hover:text-accent block px-3 py-2 text-base font-medium">
              FAQ
            </Link>
            <div className="mt-6 flex flex-col">
              <a 
                href="https://t.me/SuperQuikieBot" 
                target="_blank" 
                rel="noopener noreferrer"
              >
                <Button variant="default" className="rounded-full px-6 text-sm uppercase font-medium">
                  Get Started
                </Button>
              </a>
            </div>
          </div>
        </div>
      )}
    </nav>
  );
}
